@@ -1,10 +1,9 @@
 """
 Axislines includes modified implementation of the Axes class. The
-biggest difference is that the artists responsible to draw axis line,
-ticks, ticklabel and axis labels are separated out from the mpl's Axis
-class, which are much more than artists in the original
-mpl. Originally, this change was motivated to support curvilinear
-grid. Here are a few reasons that I came up with new axes class.
+biggest difference is that the artists responsible for drawing the axis spine,
+ticks, ticklabels and axis labels are separated out from mpl's Axis
+class. Originally, this change was motivated to support curvilinear
+grid. Here are a few reasons that I came up with a new axes class:
 
 
  * "top" and "bottom" x-axis (or "left" and "right" y-axis) can have
@@ -45,38 +44,26 @@ from the axis as some gridlines can never pass any axis.
 from __future__ import (absolute_import, division, print_function,
                         unicode_literals)
 
-from matplotlib.externals import six
-
-import matplotlib.axes as maxes
-import matplotlib.artist as martist
-import matplotlib.text as mtext
-import matplotlib.font_manager as font_manager
-
-from matplotlib.path import Path
-from matplotlib.transforms import Affine2D, ScaledTranslation, \
-     IdentityTransform, TransformedPath, Bbox
-from matplotlib.collections import LineCollection
-
-from matplotlib import rcParams
-
-from matplotlib.artist import allow_rasterization
+import six
 
 import warnings
 
 import numpy as np
 
-
-import matplotlib.lines as mlines
+from matplotlib import rcParams
+import matplotlib.artist as martist
+import matplotlib.axes as maxes
+from matplotlib.path import Path
+from matplotlib.transforms import Bbox
 from .axisline_style import AxislineStyle
-
-
 from .axis_artist import AxisArtist, GridlinesCollection
 
+
 class AxisArtistHelper(object):
     """
     AxisArtistHelper should define
     following method with given APIs. Note that the first axes argument
-    will be axes attribute of the caller artist.
+    will be axes attribute of the caller artist.::
 
 
         # LINE (spinal line?)
@@ -119,7 +106,7 @@ class AxisArtistHelper(object):
             return iter_major, iter_minor
 
 
-        """
+    """
 
     class _Base(object):
         """
@@ -246,21 +233,15 @@ class AxisArtistHelperRectlinear(object):
 
     class Fixed(AxisArtistHelper.Fixed):
 
-        def __init__(self,
-                     axes, loc, nth_coord=None,
-                     ):
+        def __init__(self, axes, loc, nth_coord=None):
             """
             nth_coord = along which coordinate value varies
             in 2d, nth_coord = 0 ->  x axis, nth_coord = 1 -> y axis
             """
-
-            super(AxisArtistHelperRectlinear.Fixed, self).__init__( \
-                     loc, nth_coord)
-
+            super(AxisArtistHelperRectlinear.Fixed, self).__init__(
+                loc, nth_coord)
             self.axis = [axes.xaxis, axes.yaxis][self.nth_coord]
 
-
-
         # TICK
 
         def get_tick_iterators(self, axes):
@@ -306,14 +287,11 @@ class AxisArtistHelperRectlinear(object):
     class Floating(AxisArtistHelper.Floating):
         def __init__(self, axes, nth_coord,
                      passingthrough_point, axis_direction="bottom"):
-
-            super(AxisArtistHelperRectlinear.Floating, self).__init__( \
+            super(AxisArtistHelperRectlinear.Floating, self).__init__(
                 nth_coord, passingthrough_point)
             self._axis_direction = axis_direction
-
             self.axis = [axes.xaxis, axes.yaxis][self.nth_coord]
 
-
         def get_line(self, axes):
             _verts = np.array([[0., 0.],
                                [1., 1.]])
@@ -511,13 +489,14 @@ class GridHelperRectlinear(GridHelperBase):
                           ):
 
         if axes is None:
-            warnings.warn("'new_floating_axis' explicitly requires the axes keyword.")
+            warnings.warn(
+                "'new_floating_axis' explicitly requires the axes keyword.")
             axes = self.axes
 
         passthrough_point = (value, value)
         transform = axes.transData
 
-        _helper = AxisArtistHelperRectlinear.Floating( \
+        _helper = AxisArtistHelperRectlinear.Floating(
             axes, nth_coord, value, axis_direction)
 
         axisline = AxisArtist(axes, _helper)
@@ -662,11 +641,10 @@ class Axes(maxes.Axes):
             axisline.major_ticklabels.set_visible(False)
             axisline.minor_ticklabels.set_visible(False)
 
-    def _get_axislines(self):
+    @property
+    def axis(self):
         return self._axislines
 
-    axis = property(_get_axislines)
-
     def new_gridlines(self, grid_helper=None):
         """
         Create and return a new GridlineCollection instance.
@@ -848,48 +826,3 @@ class AxesZero(Axes):
         self._axislines["yzero"] = yaxis_zero
 
 SubplotZero = maxes.subplot_class_factory(AxesZero)
-
-
-if 0:
-#if __name__ == "__main__":
-    import matplotlib.pyplot as plt
-
-    fig = plt.figure(1, (4,3))
-
-    ax = SubplotZero(fig, 1, 1, 1)
-    fig.add_subplot(ax)
-
-    ax.axis["xzero"].set_visible(True)
-    ax.axis["xzero"].label.set_text("Axis Zero")
-
-    for n in ["top", "right"]:
-        ax.axis[n].set_visible(False)
-
-    xx = np.arange(0, 2*np.pi, 0.01)
-    ax.plot(xx, np.sin(xx))
-    ax.set_ylabel("Test")
-    plt.draw()
-    plt.show()
-
-
-if __name__ == "__main__":
-#if 1:
-    import matplotlib.pyplot as plt
-
-    fig = plt.figure(1, (4,3))
-
-    ax = Subplot(fig, 1, 1, 1)
-    fig.add_subplot(ax)
-
-    xx = np.arange(0, 2*np.pi, 0.01)
-    ax.plot(xx, np.sin(xx))
-    ax.set_ylabel("Test")
-
-    ax.axis["top"].major_ticks.set_tick_out(True) #set_tick_direction("out")
-    ax.axis["bottom"].major_ticks.set_tick_out(True) #set_tick_direction("out")
-    #ax.axis["bottom"].set_tick_direction("in")
-
-    ax.axis["bottom"].set_label("Tk0")
-
-    plt.draw()
-    plt.show()
